aboutsummaryrefslogtreecommitdiff
path: root/python/pyspark/sql/session.py
diff options
context:
space:
mode:
authorTathagata Das <tathagata.das1565@gmail.com>2016-06-15 10:46:02 -0700
committerShixiong Zhu <shixiong@databricks.com>2016-06-15 10:46:07 -0700
commit9a5071996b968148f6b9aba12e0d3fe888d9acd8 (patch)
tree1f39691de83edb31dca56d6cd460261070504248 /python/pyspark/sql/session.py
parentd30b7e6696e20f1014c7f26aadbc051da0fac578 (diff)
downloadspark-9a5071996b968148f6b9aba12e0d3fe888d9acd8.tar.gz
spark-9a5071996b968148f6b9aba12e0d3fe888d9acd8.tar.bz2
spark-9a5071996b968148f6b9aba12e0d3fe888d9acd8.zip
[SPARK-15953][WIP][STREAMING] Renamed ContinuousQuery to StreamingQuery
Renamed for simplicity, so that its obvious that its related to streaming. Existing unit tests. Author: Tathagata Das <tathagata.das1565@gmail.com> Closes #13673 from tdas/SPARK-15953.
Diffstat (limited to 'python/pyspark/sql/session.py')
-rw-r--r--python/pyspark/sql/session.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/python/pyspark/sql/session.py b/python/pyspark/sql/session.py
index 11c815dd94..6edbd59856 100644
--- a/python/pyspark/sql/session.py
+++ b/python/pyspark/sql/session.py
@@ -565,15 +565,15 @@ class SparkSession(object):
@property
@since(2.0)
def streams(self):
- """Returns a :class:`ContinuousQueryManager` that allows managing all the
- :class:`ContinuousQuery` ContinuousQueries active on `this` context.
+ """Returns a :class:`StreamingQueryManager` that allows managing all the
+ :class:`StreamingQuery` StreamingQueries active on `this` context.
.. note:: Experimental.
- :return: :class:`ContinuousQueryManager`
+ :return: :class:`StreamingQueryManager`
"""
- from pyspark.sql.streaming import ContinuousQueryManager
- return ContinuousQueryManager(self._jsparkSession.streams())
+ from pyspark.sql.streaming import StreamingQueryManager
+ return StreamingQueryManager(self._jsparkSession.streams())
@since(2.0)
def stop(self):